event_frog_logger library
Support for doing something awesome.
More dartdocs go here.
Classes
- AccessLogger
-
Provides a
dart_frog.requestLoggerdart_frog.Middlewarethat automatically logs the access logs to the appropriate database based on the result of logDBNow - LogModel
- The Model that is used to represent all kinds of logs.
Typedefs
- DatabaseLoader = DatabaseRepository Function(RequestContext)
- Determines how to load the database from the loader